var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  NumberParam: () => NumberParam,
  ObjectParam: () => ObjectParam,
  StringParam: () => StringParam,
  default: () => useQueryParamPlugin,
  useQueryParam: () => useQueryParam,
  withDefault: () => withDefault
});
module.exports = __toCommonJS(src_exports);

// src/converters/NumberParam.ts
var NumberParam = {
  serialize: (value) => Number.isFinite(value) ? `${value}` : null,
  deserialize: (value) => {
    try {
      const parsedValue = Number.parseFloat(value);
      return Number.isFinite(parsedValue) ? parsedValue : null;
    } catch {
      return null;
    }
  }
};

// src/converters/ObjectParam.ts
function ObjectParam() {
  return {
    serialize: (value) => encodeURIComponent(JSON.stringify(value)),
    deserialize: (value) => {
      try {
        return JSON.parse(decodeURIComponent(value));
      } catch {
        return null;
      }
    }
  };
}

// src/converters/StringParam.ts
var StringParam = {
  serialize: (value) => value,
  deserialize: (value) => value ?? null
};

// src/core/useQueryParam.ts
var import_vue = require("vue");
var import_vue_router = require("vue-router");

// src/plugin/config.ts
var PROVIDE_KEY = "vue-use-query-param";

// src/core/useQueryParam.ts
function mergeUpdates(updates) {
  return updates.reduce((result, update) => {
    return {
      ...result,
      [update.name]: update.value
    };
  }, {});
}
function useQueryParam(name, { serialize, deserialize }) {
  const router = (0, import_vue_router.useRouter)();
  const route = (0, import_vue_router.useRoute)();
  const plugin = (0, import_vue.inject)(PROVIDE_KEY);
  async function updateUrl(updates) {
    const mergedUpdates = mergeUpdates(updates);
    const mergedQuery = { ...route.query, ...mergedUpdates };
    const nullProperties = Object.entries(mergedQuery).filter(([_, value]) => value === null).map(([key, _]) => key);
    nullProperties.forEach((key) => delete mergedQuery[key]);
    await router.replace({
      query: mergedQuery
    });
  }
  async function setQueryParam(value) {
    const serializedValue = serialize(value);
    plugin == null ? void 0 : plugin.queueUpdate({ name, value: serializedValue }, updateUrl);
  }
  return (0, import_vue.computed)({
    get: () => deserialize(route.query[name]),
    set: (value) => setQueryParam(value)
  });
}

// src/core/withDefault.ts
function withDefault({ serialize, deserialize }, defaultValue) {
  return {
    serialize,
    deserialize: (value) => deserialize(value) ?? defaultValue
  };
}

// src/plugin/index.ts
var import_vue2 = require("vue");
var useQueryParamPlugin = {
  install: (app, options) => {
    const queue = (0, import_vue2.ref)([]);
    const timeoutRef = (0, import_vue2.ref)(null);
    function queueUpdate(update, urlUpdate) {
      if (timeoutRef.value) {
        clearTimeout(timeoutRef.value);
      }
      queue.value.push(update);
      timeoutRef.value = setTimeout(async () => {
        await urlUpdate(queue.value);
        queue.value = [];
        timeoutRef.value = null;
      }, options.debounceDelay ?? 0);
    }
    app.provide(PROVIDE_KEY, { queueUpdate });
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  NumberParam,
  ObjectParam,
  StringParam,
  useQueryParam,
  withDefault
});
//# sourceMappingURL=index.js.map