import {
  NumberParam,
  ObjectParam,
  StringParam
} from "./chunk-BPLGHJ3D.mjs";

// src/core/useQueryParam.ts
import { computed, inject } from "vue";
import { useRoute, useRouter } from "vue-router";

// src/plugin/config.ts
var PROVIDE_KEY = "vue-use-query-param";

// src/core/useQueryParam.ts
function mergeUpdates(updates) {
  return updates.reduce((result, update) => {
    return {
      ...result,
      [update.name]: update.value
    };
  }, {});
}
function useQueryParam(name, { serialize, deserialize }) {
  const router = useRouter();
  const route = useRoute();
  const plugin = inject(PROVIDE_KEY);
  async function updateUrl(updates) {
    const mergedUpdates = mergeUpdates(updates);
    const mergedQuery = { ...route.query, ...mergedUpdates };
    const nullProperties = Object.entries(mergedQuery).filter(([_, value]) => value === null).map(([key, _]) => key);
    nullProperties.forEach((key) => delete mergedQuery[key]);
    await router.replace({
      query: mergedQuery
    });
  }
  async function setQueryParam(value) {
    const serializedValue = serialize(value);
    plugin == null ? void 0 : plugin.queueUpdate({ name, value: serializedValue }, updateUrl);
  }
  return computed({
    get: () => deserialize(route.query[name]),
    set: (value) => setQueryParam(value)
  });
}

// src/core/withDefault.ts
function withDefault({ serialize, deserialize }, defaultValue) {
  return {
    serialize,
    deserialize: (value) => deserialize(value) ?? defaultValue
  };
}

// src/plugin/index.ts
import { ref } from "vue";
var useQueryParamPlugin = {
  install: (app, options) => {
    const queue = ref([]);
    const timeoutRef = ref(null);
    function queueUpdate(update, urlUpdate) {
      if (timeoutRef.value) {
        clearTimeout(timeoutRef.value);
      }
      queue.value.push(update);
      timeoutRef.value = setTimeout(async () => {
        await urlUpdate(queue.value);
        queue.value = [];
        timeoutRef.value = null;
      }, options.debounceDelay ?? 0);
    }
    app.provide(PROVIDE_KEY, { queueUpdate });
  }
};
export {
  NumberParam,
  ObjectParam,
  StringParam,
  useQueryParamPlugin as default,
  useQueryParam,
  withDefault
};
//# sourceMappingURL=index.mjs.map